Learn R Programming

shapr (version 1.1.0)

prepare_next_iteration: Prepare the Next Iteration of the Iterative Sampling Algorithm

Description

Prepare the Next Iteration of the Iterative Sampling Algorithm

Usage

prepare_next_iteration(internal)

Value

The (updated) internal list

Arguments

internal

List. Not used directly, but passed through from explain().