Learn R Programming

shapr (version 1.1.0)

set_global_parameters: Set the global (SAGE) parameters in internal

Description

Set the global (SAGE) parameters in internal

Usage

set_global_parameters(internal)

Value

The (updated) internal list.

Arguments

internal

List. Holds all parameters, data, functions and computed objects used within explain() The list contains one or more of the elements parameters, data, objects, iter_list, timing_list, main_timing_list, output, and iter_timing_list.

Author

Martin Jullum

Details

Reads the loss function from extra_computation_args$global_loss_func, resolves the default loss function (logistic loss for binary responses, mean squared error otherwise) when none is supplied, and stores both the loss function and the baseline loss zero_loss = -loss_func(y_explain, phi0) in internal.