Function that checks provided epoch arguments
vaeac_check_epoch_values(
epochs,
epochs_initiation_phase,
epochs_early_stopping,
save_every_nth_epoch
)The function does not return anything.
Positive integer (default is 100). The number of epochs to train the final vaeac model.
This includes epochs_initiation_phase, where the default is 2.
Positive integer (default is 2). The number of epochs to run each of the
n_vaeacs_initialize vaeac models before continuing to train only the best performing model.
Positive integer (default is NULL). The training stops if there has been no
improvement in the validation IWAE for epochs_early_stopping epochs. If the user wants the training process
to be solely based on this training criterion, then epochs in explain() should be set to a large
number. If NULL, then shapr will internally set epochs_early_stopping = vaeac.epochs such that early
stopping does not occur.
Positive integer (default is NULL). If provided, then the vaeac model after
every save_every_nth_epochth epoch will be saved.
Lars Henry Berge Olsen