Function that determines which mask generator to use
vaeac_get_mask_generator_name(
mask_gen_coalitions,
mask_gen_coalitions_prob,
masking_ratio,
verbose
)The function does not return anything.
Matrix (default is NULL). Matrix containing the coalitions that the
vaeac model will be trained on, see specified_masks_mask_generator(). This parameter is used internally
in shapr when we only consider a subset of coalitions, i.e., when
n_coalitions \(< 2^{n_{\text{features}}}\), and for group Shapley, i.e.,
when group is specified in explain().
Numeric array (default is NULL). Array of length equal to the height
of mask_gen_coalitions containing the probabilities of sampling the corresponding coalitions in
mask_gen_coalitions.
Numeric (default is 0.5). Probability of masking a feature in the
mcar_mask_generator() (MCAR = Missing Completely At Random). The MCAR masking scheme ensures that vaeac
model can do arbitrary conditioning as all coalitions will be trained. masking_ratio will be overruled if
mask_gen_coalitions is specified.
String vector or NULL.
Specifies the verbosity (printout detail level) through one or more of strings "basic", "progress",
"convergence", "shapley" and "vS_details".
"basic" (default) displays basic information about the computation which is being performed.
"progress displays information about where in the calculation process the function currently is.
#' "convergence" displays information on how close to convergence the Shapley value estimates are
(only when iterative = TRUE) .
"shapley" displays intermediate Shapley value estimates and standard deviations (only when iterative = TRUE)
the final estimates.
"vS_details" displays information about the v_S estimates.
This is most relevant for approach %in% c("regression_separate", "regression_surrogate", "vaeac").
NULL means no printout.
Note that any combination of four strings can be used.
E.g. verbose = c("basic", "vS_details") will display basic information + details about the v(S)-estimation process.
Lars Henry Berge Olsen