prepare_next_iteration: Prepares the next iteration of the iterative sampling algorithm
Description
Prepares the next iteration of the iterative sampling algorithm
Usage
prepare_next_iteration(internal)
Arguments
- internal
List.
Not used directly, but passed through from explain().